# Fact Sheets
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/fact-sheets#introduction)
  * [Fact Sheet Layout](https://help.sap.com/docs/leanix/ea/fact-sheets#fact-sheet-layout)
  * [Fact Sheet Types](https://help.sap.com/docs/leanix/ea/fact-sheets#fact-sheet-types)
  * [Fact Sheet Subtypes](https://help.sap.com/docs/leanix/ea/fact-sheets#fact-sheet-subtypes)


Fact sheets in SAP LeanIX are used to record essential and comprehensive details about each architectural object, such as applications, business capabilities, IT components, etc. Learn about their structure, types, and subtypes.
